@@ -1,5 +1,5 @@
 /* GNU Ocrad - Optical Character Recognition program
-   Copyright (C) 2003-2022 Antonio Diaz Diaz.
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -238,7 +238,8 @@ int Features::test_EFIJLlT( const Charset & charset, const Rectangle & charbox )
           vbar(0).left() <= b.hpos( 30 ) )
         {
         if( hbar(0).bottom() >= botmin &&
-            b.escape_top( b.vcenter(), b.hpos( 75 ) ) )
+            b.escape_top( b.vcenter(), b.hpos( 75 ) ) &&
+            b.escape_right( b.vcenter(), b.hpos( 75 ) ) )
           return 'L';
         if( hbar(0).top() <= topmax && 2 * wp[wp.pos(50)] >= b.width() &&
             4 * wp[wp.pos(75)] < b.width() &&
