@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2014-2017 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2014-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <cstdio>
@@ -88,10 +88,9 @@ int my_fgetc( FILE * const f, const bool allow_comment = true )
   }
 
 
-// Read a line discarding comments, leading and trailing whitespace and
-// blank lines.
-// Returns the size of 'line', or 0 if at EOF.
-//
+/* Read a line discarding comments, leading and trailing whitespace, and
+   blank lines. Return the size of 'line', or 0 if at EOF.
+*/
 int my_fgets( FILE * const f, std::string & line, int & linenum )
   {
   line.clear();
@@ -168,24 +167,11 @@ int User_filter::parse_char( const std::string & line, unsigned &i ) const
   }
 
 
-void User_filter::set_file_error( const char * const file_name, const int linenum )
-  {
-  char buf[80];
-  snprintf( buf, sizeof buf, "error in file '%s', line %d.", file_name, linenum );
-  error_ = buf;
-  }
-
-
 User_filter::User_filter( const char * const file_name )
   : table1( 256, -1 ), retval_( 0 ), default_( d_discard )
   {
   FILE * const f = std::fopen( file_name, "r" );
-  if( !f )
-    {
-    error_ = "Can't open file '"; error_ += file_name; error_ += '\'';
-    retval_ = 1;
-    return;
-    }
+  if( !f ) { retval_ = 1; return; }
 
   std::string line;
   int linenum = 0;
@@ -237,12 +223,17 @@ User_filter::User_filter( const char * const file_name )
             if( !enable_char( j, new_code ) ) { retval_ = 2; break; }
           }
         }
-      else { retval_ = 2; break; }		// no set, char or range
+      else { retval_ = 2; break; }		// no set, char, or range
       if( i < line.size() && line[i] == ',' ) ++i;
       }
     }
   if( std::fclose( f ) != 0 && retval_ == 0 ) retval_ = 1;
-  if( retval_ != 0 ) set_file_error( file_name, linenum );
+  if( retval_ != 0 )
+    {
+    char buf[80];
+    snprintf( buf, sizeof buf, "error in line %d.", linenum );
+    error_ = buf;
+    }
   }
 
 
